@@ -20,7 +20,14 @@ def test_example_site(needle, myselenium):
     needle.assert_screenshot("example_site", threshold=300000)
 
 
-@pytest.mark.parametrize("name,path", [("tree", ""), ("404", "/intentional-404")])
+@pytest.mark.parametrize(
+    "name,path",
+    [
+        ("tree", ""),
+        ("404", "fake-page-404"),
+        ("404-voila", "voila/render/fake-page-404"),
+    ],
+)
 def test_voila(needle, myselenium, base_url, name, path):
     target_url = "{0}/{1}".format(base_url, path)
     needle.driver.get(target_url)
@@ -40,10 +47,10 @@ def test_apps(needle, myselenium, base_url, nb_name):
     needle.driver.get(target_url)
 
     # Wait for dashboard components to render
-    time.sleep(5)
+    time.sleep(10)
 
     # Take an element screen diff
-    needle.assert_screenshot(f"{nb_name}", threshold=800000)
+    needle.assert_screenshot(f"{nb_name}", threshold=300000)
 
 
 @pytest.mark.parametrize("nb_name", ["classes-colors", "custom-css"])
@@ -55,7 +62,19 @@ def test_customize(needle, myselenium, base_url, nb_name):
     time.sleep(5)
 
     # Take an element screen diff
-    needle.assert_screenshot(f"customize/{nb_name}", threshold=800000)
+    needle.assert_screenshot(f"customize/{nb_name}", threshold=300000)
+
+
+@pytest.mark.parametrize("nb_name", ["data-types"])
+def test_demos(needle, myselenium, base_url, nb_name):
+    target_url = "{0}/voila/render/demos/{1}.ipynb".format(base_url, nb_name)
+    needle.driver.get(target_url)
+
+    # Wait for dashboard components to render
+    time.sleep(5)
+
+    # Take an element screen diff
+    needle.assert_screenshot(f"demos/{nb_name}", threshold=300000)
 
 
 @pytest.mark.parametrize(
@@ -69,7 +88,7 @@ def test_getting_started(needle, myselenium, base_url, nb_name):
     time.sleep(5)
 
     # Take an element screen diff
-    needle.assert_screenshot(f"getting-started/{nb_name}", threshold=800000)
+    needle.assert_screenshot(f"getting-started/{nb_name}", threshold=300000)
 
 
 @pytest.mark.parametrize(
@@ -99,15 +118,15 @@ def test_layouts(needle, myselenium, base_url, nb_name):
     time.sleep(5)
 
     # Take an element screen diff
-    needle.assert_screenshot(f"layouts/{nb_name}", threshold=800000)
+    needle.assert_screenshot(f"layouts/{nb_name}", threshold=300000)
 
 
 @pytest.mark.parametrize(
     "nb_name",
     [
+        "altair-scroll",
         "altair-single",
         "altair",
-        "altair-scroll",
         "bokeh-single",
         "bokeh",
         "bqplot-single",
@@ -124,18 +143,18 @@ def test_plots(needle, myselenium, base_url, nb_name):
     time.sleep(5)
 
     # Take an element screen diff
-    needle.assert_screenshot(f"plots/{nb_name}", threshold=800000)
+    needle.assert_screenshot(f"plots/{nb_name}", threshold=300000)
 
 
 @pytest.mark.parametrize(
     "nb_name",
     [
         "ipyleaflet",
-        "ipywidgets-gallery",
-        "ipywidgets-sidebar",
+        "ipysheet",
         "mpl-histogram",
         "qgrid",
-        "ipysheet",
+        "widgets-gallery",
+        "widgets-sidebar",
     ],
 )
 def test_widgets(needle, myselenium, base_url, nb_name):
@@ -146,4 +165,4 @@ def test_widgets(needle, myselenium, base_url, nb_name):
     time.sleep(10)
 
     # Take an element screen diff
-    needle.assert_screenshot(f"widgets/{nb_name}", threshold=800000)
+    needle.assert_screenshot(f"widgets/{nb_name}", threshold=300000)
